'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ramda = require('ramda');

var _ramda2 = _interopRequireDefault(_ramda);

var _lfsCommands = require('./lfsCommands');

var _constants = require('../constants');

var _generateResponse = require('../utils/generateResponse');

var _generateResponse2 = _interopRequireDefault(_generateResponse);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var isValidFileOutput = function isValidFileOutput(str) {
  return str.includes('*') || str.includes('-');
};

var reduceResults = function reduceResults(acc, value) {
  var separatorRegex = /[*-]/;
  var match = value.match(separatorRegex);
  if (!match || !match[0]) {
    return acc;
  }

  var shaAndFileName = value.split(match[0]);
  acc[shaAndFileName[1].trim()] = shaAndFileName[0].trim();

  return acc;
};

var extractFileNames = function extractFileNames(raw) {
  var output = raw || '';

  var outputLines = output.toString().split('\n');
  var filteredLines = _ramda2.default.filter(isValidFileOutput, outputLines);
  // creating the object in which sha's point to the file name
  return _ramda2.default.reduce(reduceResults, {}, filteredLines);
};

var buildArgs = function buildArgs(options) {
  var opts = options || {};
  var args = [];

  // returns the full length OID with the file
  if (opts.long) {
    args.push('--long');
  }

  // this should probably be last?
  if (opts.commitSha && opts.commitSha > '') {
    args.push(options.commitSha);
  }

  return _ramda2.default.join(' ', args);
};

var ls = function ls(repo, options) {
  var response = (0, _generateResponse2.default)();
  var repoPath = repo.workdir();
  var args = buildArgs(options);

  return _lfsCommands.core.ls(args, { cwd: repoPath }).then(function (_ref) {
    var stdout = _ref.stdout,
        stderr = _ref.stderr;

    response.raw = stdout;

    if (stderr.length > 0) {
      response.stderr = stderr;
      response.success = false;
      response.errno = _constants.BAD_CORE_RESPONSE;
    }

    response.files = extractFileNames(stdout);
    return response;
  });
};

exports.default = ls;